access = {
    "postgres":{
        "postgres_usr": 'ti',
        "postgres_pwd": (
            'gAAAAABk_1-X_7CiiUj5MIlXyYVGdFB90RKJPblTLgUNOaFtyaXZmoMzpF6h2'
            'KyQu2TrKgjJBmdPwJtQvySgR0bHlYqJR9oHPw=='
        )
    },
}
